@@ -28,6 +28,8 @@ import pyblish
 import pyblish.lib
 import pyblish.error
 
+from pyblish.vendor import iscompatible
+
 config = pyblish.Config()
 
 
@@ -115,6 +117,11 @@ class Plugin(object):
             with each other. E.g. one plug-in may provide critical
             information to another and so must be allowed to be
             processed first.
+        optional: Whether or not plug-in can be skipped by the user.
+        requires: Which version of Pyblish is required by this plug-in.
+            Plug-ins requiring a version newer than the current version
+            will not be loaded. 1.0.8 was when :attr:`Plugin.requires`
+            was first introduced.
 
     """
 
@@ -122,6 +129,7 @@ class Plugin(object):
     version = (0, 0, 0)  # Current version of plugin
     order = None
     optional = False
+    requires = "pyblish>=1"
 
     def __str__(self):
         return type(self).__name__
@@ -175,7 +183,7 @@ class Plugin(object):
                         self.log.info("Skipping %s" % instance)
                         continue
 
-                    self.log.debug("Processing instance: %s" % instance)
+                    self.log.info("Processing instance: \"%s\"" % instance)
 
                     # Inject data
                     processed_by = instance.data('__processed_by__') or list()
@@ -360,7 +368,7 @@ class Extractor(Plugin):
 
         commit_dir = self.compute_commit_directory(instance=instance)
 
-        self.log.info("Moving {0} relative working file..".format(instance))
+        self.log.info("Moving \"%s\" relative working file.." % instance)
 
         if os.path.isdir(commit_dir):
             self.log.info("Existing directory found, merging..")
@@ -500,13 +508,12 @@ class Context(AbstractEntity):
         """
 
         instance = Instance(name, parent=self)
-        self.add(instance)
         return instance
 
 
 @pyblish.lib.log
 class Instance(AbstractEntity):
-    """An individually publishable component within scene
+    """An in-memory representation of one or more files
 
     Examples include rigs, models.
 
@@ -542,6 +549,9 @@ class Instance(AbstractEntity):
         self.name = name
         self.parent = parent
 
+        if parent is not None:
+            parent.add(self)
+
     @property
     def context(self):
         """Return top-level parent; the context"""
@@ -696,9 +706,7 @@ def environment_paths():
     env_var = config['paths_environment_variable']
     env_val = os.environ.get(env_var)
     if env_val:
-        sep = ';' if os.name == 'nt' else ':'
-        env_paths = env_val.split(sep)
-
+        env_paths = env_val.split(os.pathsep)
         for path in env_paths:
             plugin_path = _post_process_path(path)
             paths.append(plugin_path)
@@ -741,9 +749,10 @@ def discover(type=None, regex=None, paths=None):
     """Find plugins within exposed plugin-paths
 
     Arguments:
-        type (str, optional):Only return plugins of specified type
-            E.g. validators, extractors. In None is
-            specified, return all plugins.
+        type (str, optional): Only return plugins of specified type
+            E.g. validators, extractors. In None is specified, return
+            all plugins. Available options are "selectors", validators",
+            "extractors", "conformers".
         regex (str, optional): Limit results to those matching `regex`.
             Matching is done on classes, as opposed to
             filenames, due to a file possibly hosting
@@ -921,6 +930,12 @@ def _discover_type(type, paths, regex=None):
                 if not _isvalid(obj):
                     continue
 
+                if not _iscompatible(obj):
+                    log.warning(
+                        "Plug-in %s not compatible with this version "
+                        "(%s) of Pyblish." % (obj, pyblish.__version__))
+                    continue
+
                 # Only include plug-ins compatible
                 # with the currently running host.
                 if not any(["*" in obj.hosts, current_host() in obj.hosts]):
@@ -941,6 +956,18 @@ def _discover_type(type, paths, regex=None):
     return plugins.values()
 
 
+def _iscompatible(plugin):
+    """Lookup compatibility between plug-in and current version of Pyblish
+
+    Arguments:
+        plugin (Plugin): Plug-in to test against
+
+    """
+
+    return iscompatible.iscompatible(
+        requirements=plugin.requires, version=pyblish.version_info)
+
+
 def _isvalid(plugin):
     """Validate plugin"""
 
@@ -948,6 +975,10 @@ def _isvalid(plugin):
         log.error("Plug-in must have an order")
         return False
 
+    if not isinstance(plugin.requires, basestring):
+        log.error("Plug-in requires must be of type string")
+        return False
+
     # Helper functions
     def has_families(_plugin):
         if not getattr(_plugin, 'families'):
